@@ -20,14 +20,28 @@ test.LaTeX <- function() {
 			BauerEtAl2001(),
 			BretzEtAl2009a(),
 			BretzEtAl2009b(),
-			BretzEtAl2009c())
+			BretzEtAl2009c(),
+			Ferber2011())
 	
 	report <- gMCP:::LaTeXHeader()
 	for (graph in graphs) {
 		report <- paste(report, graph2latex(graph), sep="\n")
 	}
 	report <- paste(report, "\\end{document}", sep="\n")
-	#if (Sys.getenv("USER")=="kornel") cat(report, file="/home/kornel/test.tex")
+	if (interactive() && "interactive" %in% strsplit(Sys.getenv("GMCP_UNIT_TESTS"),",")[[1]]) {
+		file <- paste(Sys.getenv("GMCP_UNIT_TEST_OPATH"), "report_test.tex", sep="/")
+		cat(report, file=file)
+		exitValue <- system(paste("pdflatex", file))
+		if (exitValue != 0) {
+			stop("Error calling pdflatex.")
+		}
+		answer <- readline(paste("Does report_test.pdf look fine (Y/n)? "))
+		if (substr(answer, 1, 1) %in% c("n","N")) {
+			stop("User reported error for report_test.pdf.")
+		}
+	} else {
+		cat("Skipping interactive control of LaTeX output.\n")
+	}
 }
 
 test.fractionStrings <- function() {
